@@ -7,7 +7,7 @@ utils::globalVariables(c("yrs", "EFT", "rn"))
 
 ## Step 02 ####
 
-slp_lm <- function(x){
+slp_lm <- function(x, yrs){
   if (all(is.na(x))){
     slp <- NA
   } else if (sum(!is.na(x)) == 1){
@@ -34,7 +34,7 @@ mtid_function <- function(x){
 
 ## Step 03 ####
 
-mean_years_function <- function(x){ mean(x[yrs], na.rm = TRUE) }  #where x is the data set and yrs is a vector with the years to be averaged (e.g. yrs = c(1:3))
+mean_years_function <- function(x, yrs){ mean(x[yrs], na.rm = TRUE) }  #where x is the data set and yrs is a vector with the years to be averaged (e.g. yrs = c(1:3))
 # If x is NA for all the 'yrs', a condition might be included to take values of
 # more recent years. This is not included for now in 'mean_years_function'.
 
